=======
JSONTas
=======

JSONTas is a tool for generating dynamic JSON structures.


Contents
========

.. toctree::
   :maxdepth: 2

   Getting Started <readme>
   Examples <examples>

   License <license>
   Authors <authors>
   Contributing <contributing>
   Code of conduct <code_of_conduct>
   Changelog <changelog>
   Module Reference <api/modules>

